@@ -217,16 +217,23 @@ def rename_master_to_main(repo, org, answers, headers):
         branch_url = f"https://api.github.com/repos/{org}/{repo}/branches/master/rename"
         data = {"new_name": "main"}
 
-        rename_response = s.post(url=branch_url, headers=headers,
-                                 data=json.dumps(data))
-        if rename_response.status_code == 201:
-            logging.info("Renamed master to main")
-            return True
+        master_response = s.get(url=f"https://api.github.com/repos/{org}/{repo}/branches/master", headers=headers)
+
+        if master_response.status_code == 200:
+            rename_response = s.post(url=branch_url, headers=headers,
+                                     data=json.dumps(data))
+            if rename_response.status_code == 201:
+                logging.info("Renamed master to main")
+                return True
+            else:
+                logging.info(
+                    f"Renaming to master failed for repo {repo} due to {str(rename_response.status_code)} and response content is {rename_response.content.decode()}")
+                errors.append(repo + "| Renaming master failed")
+                return False
         else:
-            logging.info(
-                f"Renaming to master failed for repo {repo} due to {str(rename_response.status_code)} and response content is {rename_response.content.decode()}")
-            errors.append(repo + "| Renaming master failed")
-            return False
+            logging.info("No Branch named Master found, ignoring")
+            return True
+
     except Exception as ex:
         logging.exception(f"Renaming to master failed for repo {repo}")
         logging.info(ex)
