@@ -136,7 +136,7 @@ def replace_config(job_name, config, server, jenkins_answers):
         if credentials_id.strip() != "":
             config = re.sub("<credentialsId>.*</credentialsId>", f"<credentialsId>{credentials_id}</credentialsId>",
                             config)
-        config = config.replace("<name>master</name>", "<name>main</main>")
+        config = config.replace("<name>master</name>", "<name>main</name>")
         server.reconfig_job(job_name, config_xml=config)
         logging.info(f"completed configuring {job_name}")
 
